@@ -1,9 +1,12 @@
-from .article import Article, Tag  # noqa
+from .article import Article  # noqa
+from .dataset import Dataset  # noqa
+from .tag import Tag  # noqa
 from .page import Page  # noqa
 from .entity import Entity  # noqa
 from .config import Config  # noqa
 from .list_of_articles import ListOfArticles  # noqa
 from .sites import Sites  # noqa
 
-__version__ = "0.0.3"
+
+__version__ = "2.0.1"
 __status__ = "Production"
